%define module	networkx
%define name	python-%{module}
%define version	1.8.1
%define release	%mkrel 3

Summary: 	Python package for the study of complex networks
Name: 	 	%{name}
Version: 	%{version}
Release: 	%{release}
Source0: 	http://pypi.python.org/packages/source/n/networkx/%{module}-%{version}.tar.gz
License: 	BSD
Group: 	 	Development/Python
Url: 	 	https://networkx.lanl.gov/
BuildArch: 	noarch
Requires: 	python-pygraphviz
Requires: 	python-matplotlib >= 0.73.1
Suggests:	python-pyparsing
Suggests:	python-numpy, python-scipy, python-yaml
BuildRequires: 	python-setuptools, python-sphinx, python-matplotlib
BuildRequires:  python-devel
BuildRequires:  python-decorator
BuildRequires:  python-pyparsing
BuildRequires:  python-six
BuildRequires:  python3-devel
BuildRequires:  python3-decorator
BuildRequires: 	python3-setuptools
BuildRequires: 	python3-matplotlib

%description
NetworkX (NX) is a Python package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.

Features:
* Includes standard graph-theoretic and statistical physics functions
* Easy exchange of network algorithms between applications, disciplines, 
  and platforms
* Includes many classic graphs and synthetic networks
* Nodes and edges can be "anything" (e.g. time-series, text, images, 
  XML records)
* Exploits existing code from high-quality legacy software in C, C++, 
  Fortran, etc.
* Open source (encourages community input)
* Unit-tested

%package doc
Summary:        Documentation for networkx
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}

%description doc
Documentation for networkx

%package -n python3-%{module}
Summary:        Python 3 package for the study of complex networks
Group:          Development/Python
Requires:       python3-decorator
Requires:       python3-pyparsing
Requires:       python3-yaml
Requires:       python3-scipy


%description -n python3-networkx
NetworkX is a Python 3 package for the creation, manipulation, and
study of the structure, dynamics, and functions of complex networks.


%prep
%setup -q -n %{module}-%{version}
# Fix permissions
find examples -type f -perm /0111 | xargs chmod a-x
# Use the system python-decorator instead of the bundled version
sed -e '/          "networkx\.external.*",/d' \
    -e "/sys\.version >= '3'/,/^$/d" \
    -i setup.py
pushd networkx
rm -fr external
sed "/import networkx\.external/d" __init__.py > init.py
touch -r __init__.py init.py
mv -f init.py __init__.py
for f in utils/decorators.py utils/misc.py; do
  sed "s/networkx\.external\.//" $f > fixed.py
  touch -r $f fixed.py
  mv -f fixed.py $f
done
popd

cp -a . %{py3dir} 

%build
%{__python} setup.py build

pushd %{py3dir} 
%{__python3} setup.py build
popd


%install
pushd %{py3dir} 
%{__python3} setup.py install --root=%{buildroot} --skip-build 
popd

%{__python} setup.py install --root=%{buildroot} --skip-build
pushd doc
export PYTHONPATH=`dir -d ../build/lib*`
make html
popd
mv $RPM_BUILD_ROOT%{_docdir}/networkx-%{version} ./installed-docs
rm -f installed-docs/INSTALL.txt

# Fix permissions and binary paths
for f in `grep -FRl /usr/bin/env $RPM_BUILD_ROOT%{python_sitelib}`; do
  sed 's|/usr/bin/env python|%{_bindir}/python|' $f > $f.new
  touch -r $f $f.new
  chmod a+x $f.new
  mv -f $f.new $f
done

for f in `grep -FRl /usr/bin/env $RPM_BUILD_ROOT%{python3_sitelib}`; do
  sed 's|/usr/bin/env python|%{_bindir}/python3|' $f > $f.new
  touch -r $f $f.new
  chmod a+x $f.new
  mv -f $f.new $f
done

%files
%doc installed-docs/* doc/build/html
%{python_sitelib}/*

%files -n python3-%{module}
%doc installed-docs/*
%{python3_sitelib}/*

%files doc
%doc doc/build/html



%changelog
* Tue Oct 22 2013 umeabot <umeabot> 1.8.1-3.mga4
+ Revision: 543868
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.8.1-2.mga4
+ Revision: 498964
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 09 2013 philippem <philippem> 1.8.1-1.mga4
+ Revision: 476777
- Update to 1.8.1, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.7-3.mga3
+ Revision: 379160
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.7-2.mga3
+ Revision: 324753
- rebuild for Mga3 Beta1

* Sat Aug 25 2012 kamil <kamil> 1.7-1.mga3
+ Revision: 283806
- new version 1.7

* Wed Jul 04 2012 kamil <kamil> 1.6-1.mga3
+ Revision: 267115
- adapt .spec for Mageia
- imported package python-networkx

